@@ -364,7 +364,8 @@ lav_tables_stat_G2 <- function(obs.prop = NULL, est.prop = NULL, nobs = NULL) {
 
 # X2 (aka X2) statistic
 lav_tables_stat_X2 <- function(obs.prop = NULL, est.prop = NULL, nobs = NULL) {
-    X2 <- nobs*(obs.prop-est.prop)^2/est.prop
+    res.prop <- obs.prop-est.prop
+    X2 <- nobs*(res.prop*res.prop)/est.prop
     X2
 }
 
@@ -508,7 +509,7 @@ lav_tables_pairwise_table <- function(lavobject = NULL, lavdata = NULL,
             # note: MUST use 1 - pchisq (instead of lower.tail = FALSE)
             # because for ncp > 80, routine only computes lower tail
             out$RMSEA.pval <- 1.0 - pchisq(G2,
-                                           ncp = 0.1^2*out$nobs*out$df,
+                                           ncp = 0.1*0.1*out$nobs*out$df,
                                            df=out$df, lower.tail = TRUE)
         }
     }
@@ -523,7 +524,7 @@ lav_tables_pairwise_table <- function(lavobject = NULL, lavdata = NULL,
             # note: MUST use 1 - pchisq (instead of lower.tail = FALSE)
             # because for ncp > 80, routine only computes lower tail
             out$RMSEA.un.pval <- 1.0 - pchisq(G2,
-                                               ncp = 0.1^2*out$nobs*out$df,
+                                               ncp = 0.1*0.1*out$nobs*out$df,
                                                df=out$df, lower.tail = TRUE)
         }
     }
@@ -760,7 +761,7 @@ lav_tables_pairwise_freq_cell <- function(lavdata = NULL,
                       nobs = rep.int(sum(FREQ), ncell),
                        row = rep.int(seq_len(ncol), times=nrow),
                        col = rep(seq_len(nrow), each=ncol),
-                      obs.freq = vec(FREQ) # col by col!
+                      obs.freq = lav_matrix_vec(FREQ) # col by col!
                     )
             })
     }
@@ -826,14 +827,14 @@ lav_tables_pairwise_model_pi <- function(lavobject = NULL) {
                                           th.rho.vec=LONG2)
         } else {
             PI.group <- integer(0)
-            # order! first i, then j, vec(table)!
+            # order! first i, then j, lav_matrix_vec(table)!
             for(i in seq_len(nvar-1L)) {
                 for(j in (i+1L):nvar) {
                     if(ov.types[i] == "ordered" && ov.types[j] == "ordered") {
                         PI.table <- pc_PI(rho   = Sigmahat[i,j],
                                           th.y1 = TH[[g]][ th.idx[[g]] == i ],
                                           th.y2 = TH[[g]][ th.idx[[g]] == j ])
-                        PI.group <- c(PI.group, vec(PI.table))
+                        PI.group <- c(PI.group, lav_matrix_vec(PI.table))
                     }
                 }
             }
@@ -896,14 +897,14 @@ lav_tables_pairwise_sample_pi_cor <- function(COR = NULL, TH = NULL,
         ov.types[ord.idx] <- "ordered"
 
         PI.group <- integer(0)
-        # order! first i, then j, vec(table)!
+        # order! first i, then j, lav_matrix_vec(table)!
         for(i in seq_len(nvar-1L)) {
             for(j in (i+1L):nvar) {
                 if(ov.types[i] == "ordered" && ov.types[j] == "ordered") {
                     PI.table <- pc_PI(rho   = Sigmahat[i,j],
                                       th.y1 = TH[[g]][ th.idx == i ],
                                       th.y2 = TH[[g]][ th.idx == j ])
-                    PI.group <- c(PI.group, vec(PI.table))
+                    PI.group <- c(PI.group, lav_matrix_vec(PI.table))
                 }
             }
         }
